@@ -15,6 +15,20 @@ from benedict.serializers.yaml import YAMLSerializer
 import re
 
 
+__all__ = [
+    "AbstractSerializer",
+    "Base64Serializer",
+    "CSVSerializer",
+    "INISerializer",
+    "JSONSerializer",
+    "PickleSerializer",
+    "PListSerializer",
+    "QueryStringSerializer",
+    "TOMLSerializer",
+    "XMLSerializer",
+    "YAMLSerializer",
+]
+
 _BASE64_SERIALIZER = Base64Serializer()
 _CSV_SERIALIZER = CSVSerializer()
 _INI_SERIALIZER = INISerializer()
@@ -42,7 +56,7 @@ _SERIALIZERS = {
     "xml": _XML_SERIALIZER,
 }
 
-_SERIALIZERS_EXTENSIONS = [".{}".format(extension) for extension in _SERIALIZERS.keys()]
+_SERIALIZERS_EXTENSIONS = [f".{extension}" for extension in _SERIALIZERS.keys()]
 
 
 def get_format_by_path(path):
